@@ -33,4 +33,31 @@
   if (is.null(result)) return(NULL)
   if (!.http_status_ok(result)) return(NULL)
   return(result)
-}
\ No newline at end of file
+}
+
+.simplify <- function(data) {
+  empty_row <- data.frame(a = NA)[,-1]
+  result <-
+    data |>
+    lapply(tibble::enframe) |>
+    lapply(
+      tidyr::pivot_wider,
+      names_from  = "name",
+      values_from = "value")|>
+    lapply(function(x) {
+      if (nrow(x) == 0) {
+        empty_row
+      } else {
+        x
+      }
+    }) |>
+    dplyr::bind_rows() |>
+    dplyr::mutate(
+      dplyr::across(
+        dplyr::everything(),
+        function (x) {
+          if (all(lengths(x) == 1)) unlist(x) else x
+        }
+      )
+    )
+}
